# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .workspace_params_data import WorkspaceParamsData


class WorkspaceParams(UncheckedBaseModel):
    """
    Workspace params
    """

    data: WorkspaceParamsData

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
